* Encoding: windows-1252.
/*********************************************************************************************************/
/*                                                                                                                                 */
/* This SPSS program will extract the United States Sentencing Commission's                 */
/* Federa Sentencing Of Child Pornography: Production Offenses report file and create       */
/*  a SPSS dataset.                                                                                                      */
/*                                                                                                                                 */
/* Prior to running the program you must update the DAT file location in the                       */
/* FILE HANDLE DATA / NAME line to correspond to the location of the file on your           */
/* computer.                                                                                                                 */
/*                                                                                                                                 */
/* You must also update the file output location in the SAVE OUTFILE statement at the     */
/* end of the program to correspond to the folder you want the output file to be located.       */
/*                                                                                                                                 */
/*********************************************************************************************************/

/* The following line should contain the complete path and name of your raw data file */
/* The last line of this file contains the path to your output '.sav' file */

FILE HANDLE DATA / NAME=".\USSC_CP_Prod_Public.dat" ENCODING="CP1252" / LRECL=634 .

DATA LIST FILE=DATA/
   PRODCOND 1-3             SENSPCAP 4-11            AGE 12-14             
   MONSEX 15-17             NEWCIT 18-20             NEWEDUC 21-23         
   NEWRACE 24-26            SENTIMP 27-29            SENTRNGE 30-32        
   TOTCHPTS 33-35           XCRHISSR 36-38           GLMIN 39-42           
   ADJ_BHI 43-45            ADJ_CHI 46-48            ADJ_DHI 49-51         
   ADJ_EHI 52-54            ADJ_FHI 55-57            ADJ_GHI 58-60         
   ADJL_EHI 61 (A)          ADJL_GHI 62-63 (A)       GDLINEHI 64-68 (A)    
   GDSTATHI 69-73 (A)       PRODWEB 74-81            PRODOTHER 82-89       
   PRODNOCONTACT 90-97      POSSESSION 98-105        REVOCATION 106-108    
   CONTVICNUM 109-112       CONTVICSEX 113-116       CONTAGE 117-120       
   TRAVEL 121-123           PRODVICNUM 124-127       PRODVICSEX 128-131    
   PRODAGE 132-135          PRODHOUSE 136-139        PRODPARENT 140-143    
   PRODSTEP 144-147         PRODINTIM 148-151        PRODSIB 152-155       
   PRODREL 156-159          PRODGUARD 160-163        PRODFRIEND 164-167    
   PRODCOACH 168-171        PRODINTREL 172-175       PRODSTRANGE 176-179   
   PRODUNKNOW 180-183       PRODMISREP 184-187       PRODPHONE 188-191     
   PRODSOCIAL 192-195       PRODLIVE 196-199         PRODGAMES 200-203     
   PRODPERSON 204-207       PRODENTICE 208-211       PRODDRUG 212-215      
   VIOLENCE 216-219         THREAT 220-223           BULLY 224-227         
   EXTORTION 228-231        OTHERPRESS 232-235       PRODDIRECT 236-239    
   PRODWORK 240-243         PRODCAM 244-247          PRODVICTIM 248-251    
   PRODDEVOTH 252-255       PRODHIDE 256-259         PDIST 260-263         
   COMMMIPIC 264-266        COMMUNITY 267-274        NEWCOND10 275-282     
   NEWCOND11 283-290        COLLEGE 291-298          SINGLE_SRDUM 299-306  
   RDSO 307-314             SEXSTATHI 315-322        PRODMINFIG 323-330    
   PRODVNUM 331-338         PRODGROUP 339-346        WORK 347-354          
   MISREP 355-362           ENTICE 363-370           PRODCOERCE 371-378    
   COERCE 379-386           MIEC 387-394             PRODPRES 395-402      
   PRODCONTACT1 403-410     PRODSELF 411-418         PRODNOTOUCH 419-426   
   PRODCONTACT 427-434      METHOD1 435-442          METHOD2 443-450       
   MULTICOMM 451-458        PRODSMARTTAB 459-466     PRODLIVECAM 467-474   
   NONPDIST 475-482         POSSDISTCOMM 483-490     NONCONMINOR1 491-498  
   NONCONMINOR2 499-506     NONCONMINOR3 507-514     SOLICIT 515-522       
   EXPLOIT 523-530          ANYPORN 531-538          ANYADULT 539-546      
   ANYNONCONTACT 547-554    ANYSEXCH 555-562         ANYMINOR 563-570      
   ANYCONTACT2 571-578      CONTACT 579-586          ONLINE 587-594        
   MULTIPLE 595-602         PRODRELATEHI 603-610     ANYCHPTS 611-618      
   PRODINTER 619-626        IDNUM 627-634 .       


FORMATS
  SENSPCAP (F9.2) / .
   
VARIABLE LABELS
   PRODCOND 'Production Conduct'
   PRODWEB 'Contact via any other website'
   PRODOTHER 'Contact via other means'
   PRODNOCONTACT    'No contact was made; produced without the knowledge of the victim' +
   '(s)'
   POSSESSION 'Offender Possessed Child Pornography'
   REVOCATION 'Revocation'
   CONTVICNUM 'Number of Contact Victims'
   CONTVICSEX 'Sex of Contact Victims'
   CONTAGE 'Age of youngest contact victim'
   TRAVEL 'Travel with Intent'
   PRODVICNUM 'Number of Production Victims'
   PRODVICSEX 'Sex of Production Victims'
   PRODAGE 'Age of youngest production victim'
   PRODHOUSE 'Live in Household with Victim'
   PRODPARENT 'Parent of Victim'
   PRODSTEP 'Step-parent of Victim'
   PRODINTIM "Intimate Partner of Victim's Parent"
   PRODSIB 'Sibling of Victim'
   PRODREL 'Other Relative of Victim'
   PRODGUARD 'Legal Guardian of Victim'
   PRODFRIEND "Family friend of victim or victim's parents"
   PRODCOACH 'Non familial coach, teacher, et al. of victim'
   PRODINTREL 'Stranger met over the internet'
   PRODSTRANGE '"Other" stranger to victim'
   PRODUNKNOW 'Relationship to Victim is Unknown'
   PRODMISREP 'Misrepresentation'
   PRODPHONE 'Contact via Phone Conversation'
   PRODSOCIAL 'Contact via social media platform'
   PRODLIVE 'Contact via live streaming or video chat'
   PRODGAMES 'Contact via video games'
   PRODPERSON 'Contact in person'
   PRODENTICE 'Entice or Induce Victim(s)'
   PRODDRUG 'Incapacitate Victim(s)'
   VIOLENCE 'Violence Used'
   THREAT 'Violence Threatened'
   BULLY 'Non-violent, non-sexual pressure'
   EXTORTION '"Sextortion" used'
   OTHERPRESS '"Other" forms of pressure used'
   PRODDIRECT 'Direct the Victim(s)'
   PRODWORK 'Work with others'
   PRODCAM 'Offender used anotther type of camera, such as a video camera'
   PRODVICTIM 'Victim produced pornography at the direction of the offender'
   PRODDEVOTH 'Offender used some other device'
   PRODHIDE 'Hidden Camera or Filming Device'
   PDIST 'Offender Distributed Pornography Produced'
   COMMMIPIC 'Solicit minor for pictures'
   COMMUNITY 'Any Community Participation'
   NEWCOND10 'Sent pornography to minors'
   NEWCOND11 'Other non-contact sex offenses'
   COLLEGE 'Offender had at least some college'
   SINGLE_SRDUM 'Binary within manual/variance flag'
   RDSO 'Offender received 4B1.5'
   SEXSTATHI 'Type of sex offense based on most serious statute of conviction'
   PRODMINFIG 'Categorical Production MM for Pie Chart'
   PRODVNUM 'Collapsed Number of Production Victims'
   PRODGROUP 'Production Victim Age Groups'
   WORK 'Offender worked with others'
   MISREP 'Offender misrepresented identity'
   ENTICE 'Offender used enticements'
   PRODCOERCE 'Number of types of coercion used'
   COERCE 'Offender used coercion'
   MIEC 'Used misrep, incapacitation, enticement, or coercion'
   PRODPRES 'Offender was present during production'
   PRODCONTACT1 'Offender or co-participant sexually contacted victim'
   PRODSELF 'Only contact was by victim'
   PRODNOTOUCH 'No sexual contact during production'
   PRODCONTACT 'Sexual contact during production'
   METHOD1 'Contact via virtual means'
   METHOD2 'Contact in person'
   MULTICOMM 'Communication methods breakdown'
   PRODSMARTTAB 'Produced via smartphone or tablet'
   PRODLIVECAM 'Produced via livestreaming or webcam'
   NONPDIST 'Distributed non-produced images'
   POSSDISTCOMM    'Engaged with CP outside of production or participated in communit' +
   'y'
   NONCONMINOR1    'Offender has arrest, dismissed or pending charges for contact sex' +
   ' offense against minor'
   NONCONMINOR2 'Admission of contact sex offense against minor'
   NONCONMINOR3 'Allegation of contact offense against a minor'
   SOLICIT 'Solicitation of a minor for sexual abuse or contact'
   ANYPORN 'Any CH non-production CP events'
   ANYADULT 'Any CH Contact with Adult'
   ANYNONCONTACT 'Any CH Non Contact Event'
   ANYSEXCH 'Any CH Sex Offense Events'
   ANYMINOR 'Any CH Contact with a Minor or Statrape'
   ANYCONTACT2 'Any prior contact offense against a minor'
   ONLINE 'Offender used online means to contact victim'
   MULTIPLE 'Offender used multiple methods to contact victim'
   PRODRELATEHI "Offender's closest relationship to a victim"
   ANYCHPTS 'Offender had any criminal history points'
   PRODINTER 'Contact via Text/Email/IM'
.

SAVE OUTFILE='.\USSC_CP_Prod_Public.sav'.
